@@ -1,9 +1,8 @@
 from dataclasses import dataclass
-from inspect import isclass
 
 import httpx
 from fastapi import HTTPException
-from pydantic import BaseModel
+from pydantic import TypeAdapter
 
 
 @dataclass
@@ -18,8 +17,9 @@ class ReplaceMicroserviceConfig:
 
 
 class BaseMicroserviceClient:
-    async def send(self, url: str, query_params: dict, body_params: any, response_type: any,
-                   option: MicroserviceOption = None):
+    async def send(
+        self, url: str, query_params: dict, body_params: any, response_type: any, option: MicroserviceOption = None
+    ):
         if not ReplaceMicroserviceConfig.url:
             raise Exception("Please config microservice url")
 
@@ -41,7 +41,4 @@ class BaseMicroserviceClient:
             if not response_type:
                 return data
 
-            if isclass(response_type) and issubclass(response_type, BaseModel):
-                return response_type.model_validate(data)
-
-            return response_type(data)
+            return TypeAdapter(response_type).validate_python(data)
