@@ -1,5 +1,5 @@
 import typing
-from dataclasses import field, dataclass
+from dataclasses import dataclass, field
 
 
 @dataclass
@@ -15,6 +15,7 @@ class GenerationPropertyDetail:
     default_value: typing.Optional[any] = None
     default_factory: typing.Optional[any] = None
     allow_none: bool = False
+    is_enum: bool = False
 
 
 @dataclass
